@@ -43,6 +43,7 @@ constant(const char *name)
         case 'H':
             if (strEQ(name, "HTTP_VERSION_1_0")) return CURL_HTTP_VERSION_1_0;
             if (strEQ(name, "HTTP_VERSION_1_1")) return CURL_HTTP_VERSION_1_1;
+            if (strEQ(name, "HTTP_VERSION_2")) return CURL_HTTP_VERSION_2;
             if (strEQ(name, "HTTP_VERSION_2_0")) return CURL_HTTP_VERSION_2_0;
             if (strEQ(name, "HTTP_VERSION_NONE")) return CURL_HTTP_VERSION_NONE;
             break;
@@ -797,7 +798,9 @@ constant(const char *name)
             break;
         case 'P':
             if (strEQ(name, "PASSWORD")) return CURLOPT_PASSWORD;
+            if (strEQ(name, "PATH_AS_IS")) return CURLOPT_PATH_AS_IS;
             if (strEQ(name, "PINNEDPUBLICKEY")) return CURLOPT_PINNEDPUBLICKEY;
+            if (strEQ(name, "PIPEWAIT")) return CURLOPT_PIPEWAIT;
             if (strEQ(name, "PORT")) return CURLOPT_PORT;
             if (strEQ(name, "POST")) return CURLOPT_POST;
             if (strEQ(name, "POST301")) return CURLOPT_POST301;
@@ -819,6 +822,7 @@ constant(const char *name)
             if (strEQ(name, "PROXYTYPE")) return CURLOPT_PROXYTYPE;
             if (strEQ(name, "PROXYUSERNAME")) return CURLOPT_PROXYUSERNAME;
             if (strEQ(name, "PROXYUSERPWD")) return CURLOPT_PROXYUSERPWD;
+            if (strEQ(name, "PROXY_SERVICE_NAME")) return CURLOPT_PROXY_SERVICE_NAME;
             if (strEQ(name, "PROXY_TRANSFER_MODE")) return CURLOPT_PROXY_TRANSFER_MODE;
             if (strEQ(name, "PUT")) return CURLOPT_PUT;
             break;
@@ -848,6 +852,7 @@ constant(const char *name)
             if (strEQ(name, "SEEKDATA")) return CURLOPT_SEEKDATA;
             if (strEQ(name, "SEEKFUNCTION")) return CURLOPT_SEEKFUNCTION;
             if (strEQ(name, "SERVER_RESPONSE_TIMEOUT")) return CURLOPT_SERVER_RESPONSE_TIMEOUT;
+            if (strEQ(name, "SERVICE_NAME")) return CURLOPT_SERVICE_NAME;
             if (strEQ(name, "SHARE")) return CURLOPT_SHARE;
             if (strEQ(name, "SOCKOPTDATA")) return CURLOPT_SOCKOPTDATA;
             if (strEQ(name, "SOCKOPTFUNCTION")) return CURLOPT_SOCKOPTFUNCTION;
@@ -874,6 +879,7 @@ constant(const char *name)
             if (strEQ(name, "SSL_CTX_FUNCTION")) return CURLOPT_SSL_CTX_FUNCTION;
             if (strEQ(name, "SSL_ENABLE_ALPN")) return CURLOPT_SSL_ENABLE_ALPN;
             if (strEQ(name, "SSL_ENABLE_NPN")) return CURLOPT_SSL_ENABLE_NPN;
+            if (strEQ(name, "SSL_FALSESTART")) return CURLOPT_SSL_FALSESTART;
             if (strEQ(name, "SSL_OPTIONS")) return CURLOPT_SSL_OPTIONS;
             if (strEQ(name, "SSL_SESSIONID_CACHE")) return CURLOPT_SSL_SESSIONID_CACHE;
             if (strEQ(name, "SSL_VERIFYHOST")) return CURLOPT_SSL_VERIFYHOST;
